==> haskell-trifecta-1.5.2-14-armv7h.pkg.tar.xz: usr/share/haskell/haskell-trifecta/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.5.2
id: trifecta-1.5.2-d68d0d1e7b3496d83e34c521f475c3b5
key: trife_48U0rXNc4Y8KPfvzqYSRO1
license: BSD3
copyright: Copyright (C) 2010-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
hs-libraries: HStrifecta-1.5.2-48U0rXNc4Y8KPfvzqYSRO1
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
    comonad-5-eb230ef163a26fe6410daceeb92d736a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    lens-4.13.2.1-e19d77b9fe276f1aacdf6ec68343ec35
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsers-0.12.3-1e35467efed8fe38d8f3b579df5912e3
    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
    reducers-3.12.1-945b6d2d7be706517694521697039a82
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-1.5.2-17-armv7h.pkg.tar.xz: usr/share/haskell/haskell-trifecta/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.5.2
id: trifecta-1.5.2-a4e623d94436bd388be847118406383a
key: trife_L0IOnV8BQMbANyUe9gC9YX
license: BSD3
copyright: Copyright (C) 2010-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
hs-libraries: HStrifecta-1.5.2-L0IOnV8BQMbANyUe9gC9YX
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    charset-0.3.7.1-efbce7d7e6d5ad9047eb0bb349210702
    comonad-5-9b3bac8b2740903020c84a0c2eebf7b2
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    lens-4.14-628d47acbc5f1414216cede3732a90db
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsers-0.12.3-b2fd1876091e767ae50d1584dc543a51
    profunctors-5.2-5f15e32dcb12ed9b3b3c97537d07181e
    reducers-3.12.1-e18fca3ee2096c40c88476933be83bab
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
